Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: tools/gn/bundle_data.h

Issue 2105613003: Fix dependencies rules for create_bundle and bundle_data ninja steps. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove stamps (to allow using hardlinks) Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/gn/BUILD.gn ('k') | tools/gn/bundle_data.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gn/bundle_data.h
diff --git a/tools/gn/bundle_data.h b/tools/gn/bundle_data.h
index 0b040f7f5b29bd627c33e095d3260a7ab26eedce..e35cacb4051e7f5256440069178512c79acf38fd 100644
--- a/tools/gn/bundle_data.h
+++ b/tools/gn/bundle_data.h
@@ -19,19 +19,6 @@ class OutputFile;
class Settings;
class Target;
-// Returns true if |source| correspond to the path of a file in an asset
-// catalog. If defined |asset_catalog| is set to its path.
-//
-// An asset catalog is an OS X bundle with the ".xcassets" extension. It
-// contains one directory per assets each of them with the ".imageset"
-// extension.
-//
-// All asset catalogs are compiled by Xcode into single Assets.car file as
-// part of the creation of an application or framework bundle. BundleData
-// emulates this with the "compile_xcassets" tool.
-bool IsSourceFileFromAssetCatalog(const SourceFile& source,
- SourceFile* asset_catalog);
-
// BundleData holds the information required by "create_bundle" target.
class BundleData {
public:
@@ -64,7 +51,7 @@ class BundleData {
SourceFiles* outputs_as_source) const;
// Returns the path to the compiled asset catalog. Only valid if
// asset_catalog_sources() is not empty.
SourceFile GetCompiledAssetCatalogPath() const;
// Returns the path to the top-level directory of the bundle. This is
@@ -83,9 +70,14 @@ class BundleData {
SourceDir GetBundleRootDirOutputAsDir(const Settings* settings) const;
// Returns the list of inputs for the compilation of the asset catalog.
- SourceFiles& asset_catalog_sources() { return asset_catalog_sources_; }
- const SourceFiles& asset_catalog_sources() const {
- return asset_catalog_sources_;
+ SourceFiles& assets_catalog_sources() { return assets_catalog_sources_; }
+ const SourceFiles& assets_catalog_sources() const {
+ return assets_catalog_sources_;
+ }
+
+ // Returns the list of dependencies for the compilation of the asset catalog.
+ std::vector<const Target*> assets_catalog_deps() const {
+ return assets_catalog_deps_;
}
BundleFileRules& file_rules() { return file_rules_; }
@@ -132,7 +124,8 @@ class BundleData {
const UniqueTargets& bundle_deps() const { return bundle_deps_; }
private:
- SourceFiles asset_catalog_sources_;
+ SourceFiles assets_catalog_sources_;
+ std::vector<const Target*> assets_catalog_deps_;
BundleFileRules file_rules_;
UniqueTargets bundle_deps_;
« no previous file with comments | « tools/gn/BUILD.gn ('k') | tools/gn/bundle_data.cc » ('j') | no next file with comments »
@@ -64,7 +51,7 @@ class BundleData {
SourceFiles* outputs_as_source) const;
// Returns the path to the compiled asset catalog. Only valid if
- // asset_catalog_sources() is not empty.
+ // assets_catalog_sources() is not empty.
SourceFile GetCompiledAssetCatalogPath() const;
// Returns the path to the top-level directory of the bundle. This is

Powered by Google App Engine
This is Rietveld 408576698